from pathlib import Path

#
import pyautogui as pyg


def busca_img(
    imagem: Path, busca: str = "rapida", confiabilidade: float = 0.9
) -> tuple[int, int] | None:
    """
    Usa o pyautogui para retornar as coordenadas x, y da imagem.

    Args:
        imagem (Path): caminho da imagem.
        busca (str): tipo de busca ('lenta', 'normal', 'rapida').
        confiabilidade (float): nível de precisão da imagem.

    Returns:
        tupla ou None: retorna as coordenadas (x, y) em uma tupla ou
            None se não encontrar.

    Exemplo:
        cordenadas = busca_img("caminho/completo/imagem.png",
            busca="rapida")
    """


    tipos_de_busca = {
        "lenta": (1200, 0.5),
        "normal": (120, 0.5),
        "rapida": (1, 0.5),
    }

    # Verifica se o valor para busca está correto
    if busca not in tipos_de_busca:
        raise ValueError(
            f"Valor de busca inválido. Opções: {list(tipos_de_busca.keys())}"
        )

    #
    tentativas, atraso = tipos_de_busca[busca]

    for tentativa in range(tentativas):
        try:
            pyg.sleep(atraso)
            cordenadas = pyg.locateCenterOnScreen(
                str(imagem), grayscale=True, confidence=confiabilidade
            )

            # Caso ache as cordenadas da imagem
            if cordenadas:
                if tentativa > 0:
                    print(
                        f"Imagem {imagem.name} encontrada após\
                        {tentativa + 1} tentativas."
                    )
                return cordenadas


        except pyg.ImageNotFoundException:
            continue


        except Exception as e:
            print(f"Erro durante a busca da imagem: {e}")
            raise

    if busca != "rapida":
        print("Imagem não encontrada após o número máximo de tentativas")
    return None


def clica_na_imagem(
    imagem: Path,
    busca: str = "normal",
    double: bool = False,
    duracao: float = 0.5
) -> None:
    """
    Clica nas cordenadas da imagem informada.

    Args:
        imagem (Path): caminho da imagem.
        busca (str): tipo de busca ('lenta', 'normal', 'rapida').
        double (bool): define o click duplo.
        duracao (float): temo que o cursor levará para se mover até as
            cordenadas da imagem.
    """
    coordenadas = busca_img(imagem, busca=busca)
    try:
        if double:
            pyg.doubleClick(coordenadas)
        else:
            pyg.click(coordenadas, duration=duracao)
        print(f"Imagem {imagem.name} clicada")
    except Exception as e:
        print(f"Erro ao tentar clicar na imagem: {e}")



from pathlib import Path

home = Path.home()

certificado_advys_gov = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_certificado_advys_gov.png'
gov_confirm_robo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_gov_confirm_robo.png'
gov_confirm_robo_prosseguir = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_gov_confirm_robo_prosseguir.png'
titulo_filtros = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\diversos\img_titulo_filtros.png'
calcular = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calcular.png'
calculo_abortado = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_abortado.png'
calculo_avisos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_avisos.png'
calculo_avisos_0 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_avisos_0.png'
calculo_finalizado = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_finalizado.png'
calculo_finalizado_0 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_finalizado_0.png'
calculo_nao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_calculo_nao.png'
competencia_calculada = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\calculo\img_competencia_calculada.png'
janela_avisos_vencimento = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\dominio\img_janela_avisos_vencimento.png'
chkbx_fechamento = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_fechamento.png'
chkbx_pagamentos_trabalhador = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_pagamentos_trabalhador.png'
chkbx_remuneracao_trabalhador = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_remuneracao_trabalhador.png'
chkbx_transmissao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_chkbx_transmissao.png'
competencia_fechada_esocial = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_competencia_fechada_esocial.png'
dctf_atencao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_dctf_atencao.png'
eventos_enviados = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_eventos_enviados.png'
janela_validados_periodo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_janela_validados_periodo.png'
relatorio_validados = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_relatorio_validados.png'
select_evento_informado = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_select_evento_informado.png'
sem_dados_para_emitir = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_sem_dados_para_emitir.png'
stattus_esocial_diferente = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_stattus_esocial_diferente.png'
validados_opcoes_nenhum = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_validados_opcoes_nenhum.png'
validados_painel_periodo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\fechamento\img_validados_painel_periodo.png'
btn_continue_atualizacao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_btn_continue_atualizacao.png'
dominio_web = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web.png'
dominio_web_carregando = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web_carregando.png'
dominio_web_lista_programas = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web_lista_programas.png'
dominio_web_lista_programas_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_dominio_web_lista_programas_1.png'
erro_impossivel_localizar = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_erro_impossivel_localizar.png'
icone_escrita_fiscal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_icone_escrita_fiscal.png'
icone_folha = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_icone_folha.png'
login_fiscal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_login_fiscal.png'
logo_dominio = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_logo_dominio.png'
logo_escrita_fiscal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_logo_escrita_fiscal.png'
logo_folha = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_logo_folha.png'
permitir_plugin = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_permitir_plugin.png'
permitir_plugin_en = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\img_permitir_plugin_en.png'
logo_thomson = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\login dominio web\imt_logo_thomson.png'
aviso_rubrica = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_aviso_rubrica.png'
chkbx_pagamentos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_chkbx_pagamentos.png'
chkbx_remuneracao_1200 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_chkbx_remuneracao_1200.png'
eventos_atencao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_eventos_atencao.png'
pag_eventos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\pagamentos remuneracao\img_pag_eventos.png'
btn_reticencias = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_btn_reticencias.png'
classificacao_tributaria = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_classificacao_tributaria.png'
classificacao_tributaria_selecionada = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_classificacao_tributaria_selecionada.png'
icone_salvar = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_icone_salvar.png'
janela_extrato_mensal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_extrato_mensal.png'
janela_liquidos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_liquidos.png'
janela_recibo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_recibo.png'
janela_resumo = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_janela_resumo.png'
opt_classificacao_tributaria = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_opt_classificacao_tributaria.png'
radio_todos = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_radio_todos.png'
relacao_empresas = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relacao_empresas.png'
relatorios_caminho = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorios_caminho.png'
relatorios_salvar = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorios_salvar.png'
relatorio_adobe = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_adobe.png'
relatorio_class_tributaria = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_class_tributaria.png'
relatorio_erro_gravacao = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_erro_gravacao.png'
relatorio_extrato_mensal = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_extrato_mensal.png'
relatorio_liquidos_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_liquidos_1.png'
relatorio_liquidos_2 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_liquidos_2.png'
relatorio_recibo_folha_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_recibo_folha_1.png'
relatorio_recibo_folha_2 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_recibo_folha_2.png'
relatorio_resumo_folha_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_resumo_folha_1.png'
relatorio_resumo_folha_2 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_relatorio_resumo_folha_2.png'
select_planilha_cabecalho = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_select_planilha_cabecalho.png'
select_visualizador_w = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_select_visualizador_w.png'
sem_dados = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\relatorios\img_sem_dados.png'
erro_criar_parametro = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_erro_criar_parametro.png'
erro_sem_parametro = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_erro_sem_parametro.png'
janela_troca_empresa = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_janela_troca_empresa.png'
radio_busca_cod = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\dominio web\selecionar empresa\img_radio_busca_cod.png'
btn_alterar_perfil = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_btn_alterar_perfil.png'
btn_alterar_perfil_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_btn_alterar_perfil_1.png'
input_pessoa_juridica = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_input_pessoa_juridica.png'
input_pessoa_juridica_1 = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\alterar_perfil\img_input_pessoa_juridica_1.png'
entrar_gov = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\login_ecac\img_entrar_gov.png'
login_gov = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\login_ecac\img_login_gov.png'
btn_emitir_darf = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI\Advys - Documentos\COMUM\20- IMAGENS\ecac\relatorios\img_btn_emitir_darf.png'



from pathlib import Path
from pydantic import ValidationError
import pytest

from advys_validadores.arquivo import Arquivo


def test_caminho_valido():
    with pytest.raises(ValidationError):
        Arquivo(caminho=Path(__file__).parent)

def test_caminho_string():
    with pytest.raises(ValidationError):
        Arquivo(caminho="caminho/inválido")



import argparse
from pathlib import Path

#
from advys_estrutura.utils import cria_arquivo_python, adiciona_linha_ao_arquivo
from advys_estrutura.config import DIR_DESENVOLVIMENTO_REDE, IMAGENS_PY
from advys_configuracoes.config_ini import carrega_configuracao_ini


#
def criar_caminhos_imagem(dir_imagens:Path, arquivo_imagens_py,iniciar=True):
    if iniciar:
        cria_arquivo_python(arquivo_imagens_py)
    for item in dir_imagens.iterdir():
        if item.is_file() and item.suffix == ".png":
            linha = f"{item.stem[4:]} = home / '{item.relative_to(Path.home())}'"
            adiciona_linha_ao_arquivo(linha, arquivo_imagens_py)

        if item.is_dir():
            criar_caminhos_imagem(item, arquivo_imagens_py, iniciar= False)

def executa_atualização():
    # Carrega o arquivo de configuração
    config_ini = carrega_configuracao_ini()

    parser = argparse.ArgumentParser(
        description="Gera atualiza o arquivo imagens.py")
    parser.add_argument("-ci", "--caminho_imagens",
                        help="Caminho para pasta de imagens")
    args = parser.parse_args()

    dir_imagens = config_ini["atualiza_imagens"]["caminho_imagens"]
    if args.caminho_imagens:
        dir_imagens = args.caminho_imagens

    criar_caminhos_imagem(Path(dir_imagens), IMAGENS_PY)


if __name__ == "__main__":
    executa_atualização()


from email.mime.multipart import MIMEMultipart
from email.mime.application import MIMEApplication
from email.mime.text import MIMEText
import logging
import smtplib
from pathlib import Path

#
from advys_validadores.emal import Usuario
from advys_validadores.senha import SenhaSimples
from advys_validadores.arquivo import Arquivo


class EmailSmtp:

    def __init__(
        self,
        endereco_email: str,
        senha: str,
        servidor: str = "smtp.gmail.com",
        porta: int = 587
    ):
        """
        Inicializa o objeto EmailSmtp.

        Args:
            endereco_email: Usuario gmail para envio do email via smtp.
            senha: Senha gmail destinada a aplicativos externos.
            servidor: Servidor usado para enviar email, padrão smtp.gmail.com.
            porta: Porta do servidor usada para enviar email, padrão 587.
        """
        self.servidor = servidor
        self.porta = porta
        self.endereco_email = Usuario(email=endereco_email).email
        self.senha = SenhaSimples(valor=senha).valor
        self.email_mime = None

    @property
    def email(self):
        return self.endereco_email

    @property
    def remetente(self):
        return self.endereco_email

    def criar_email_mime(
        self,
        destinatarios: list[str],
        assunto: str,
        mensagem: str,
        copia_para: list[str] = None
    ) -> None:
        """
        Cria o corpo do email (MIME).

        Args:
            destinatarios: Endereços de e-mail dos destinatários.
            assunto: Assunto do email.
            mensagem: Corpo do e-mail em formato HTML.
            copia_para: Endereços de e-mail para enviar uma cópia.

        Raises:
            ValueError: Se a lista de destinatários estiver vazia.
        """
        self.destinatarios = destinatarios
        self.assunto = assunto
        self.copia_para = copia_para or []

        if not destinatarios:
            raise ValueError("Lista de destinatários vazia!")

        # Criação do email (objeto MIMEMultipart)
        email_mime = MIMEMultipart()
        email_mime["From"] = self.remetente
        email_mime["To"] = ", ".join(self.destinatarios)
        email_mime["Subject"] = self.assunto
        if self.copia_para:
            email_mime["Cc"] = ", ".join(self.copia_para)

        # Adiciona a mensagem ao corpo email no formato html
        email_mime.attach(MIMEText(mensagem, "html"))

        #
        self.email_mime = email_mime

    def anexar_arquivo(self, arquivos: list[Path]) -> None:
        """
        Anexa o arquivo ao corpo do email (MIME).

        Args:
            arquivos (list): Arquivos (caminhos) para anexar ao e-mail.

        """

        logging.info("Anexando arquivos")
        for arquivo in arquivos:
            try:
                caminho_arquivo = Arquivo(caminho=arquivo).caminho
                nome_arquivo = caminho_arquivo.name
                with open(caminho_arquivo, "rb") as attachment:
                    part = MIMEApplication(
                        attachment.read(), Name=nome_arquivo
                    )
                    part["Content-Disposition"] = (
                        f'attachment; filename="{nome_arquivo}"'
                    )
                    self.email_mime.attach(part)
                logging.debug(f"{nome_arquivo} - anexado com sucesso")
            except Exception as e:
                logging.error(
                    f"Erro ao anexar arquivo {arquivo.name}: {e}"
                )
        logging.info("Arquivos anexados.")

    def enviar_email(self) -> None:
        """
        Envia o email para todos os destinatários.

        Raises:
            ValueError: Se o email não for criado.
        """
        if not self.email_mime:
            raise ValueError("O e-mail não foi criado!")

        try:
            destinatarios_com_copia = (
                self.destinatarios + self.copia_para
            )

            with smtplib.SMTP(self.servidor, self.porta) as server:
                server.starttls()
                server.login(self.email, self.senha.get_secret_value())
                server.sendmail(
                    self.remetente,
                    destinatarios_com_copia,
                    self.email_mime.as_string()
                )
            logging.info(f'Destinatários:{", ".join(self.destinatarios)}')
            logging.info(f"E-mail enviado com sucesso!")

        except Exception as e:
            logging.error(f"Erro ao enviar email: {e}")



from functools import wraps
from advys_configuracoes.config_ini import arquivo_ini, cria_pyadvys_ini

def cria_config_ini(func):
    @wraps(func)
    def wrapper(*args, **kwargs):
        if not arquivo_ini.exists():
            cria_pyadvys_ini()
        return func(*args, **kwargs)
    return wrapper


import logging
from logging.handlers import RotatingFileHandler
from pathlib import Path

def configurar_logging(
    arquivo_log,
    max_bytes=5 * 1024 * 1024,  # 5MB
    backup_count=3,
    habilitar_log_console=False,
):
    caminho = Path(arquivo_log)
    caminho.parent.mkdir(exist_ok=True, parents=True)

    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)

    # Formato do log
    formato = logging.Formatter(
        '%(asctime)s | %(levelname)s | %(name)s | %(message)s'
    )

    # Handler para arquivo com rotação
    file_handler = RotatingFileHandler(
        arquivo_log, maxBytes=max_bytes, backupCount=backup_count
    )
    file_handler.setFormatter(formato)

    # Handler opcional para console
    console = None
    if habilitar_log_console:
        console = logging.StreamHandler()
        console.setFormatter(formato)


    # Adiciona os handlers caso não existam
    if not logger.handlers:
        logger.addHandler(file_handler)
        if console:
            logger.addHandler(console)


import pytest
from unittest.mock import patch, MagicMock

from advys_servicos.email_smtp import EmailSmtp

# Configuração inicial para o teste
EMAIL = "teste@gmail.com"
SENHA = "senha123"
DESTINATARIO = ["destinatario@gmail.com"]
ASSUNTO = "Teste"
MENSAGEM = "<p>Mensagem de teste</p>"



@pytest.fixture
def email_smtp():
    return EmailSmtp(endereco_email=EMAIL, senha=SENHA)

def test_criar_email_mime(email_smtp):
    email_smtp.criar_email_mime(
        destinatarios=DESTINATARIO,
        assunto=ASSUNTO,
        mensagem=MENSAGEM
    )
    assert email_smtp.email_mime is not None
    assert email_smtp.email_mime["Subject"] == ASSUNTO

@patch("advys_servicos.email_smtp.smtplib.SMTP")
def test_enviar_email(mock_smtp, email_smtp):
    email_smtp.criar_email_mime(
        destinatarios=DESTINATARIO,
        assunto=ASSUNTO,
        mensagem=MENSAGEM
    )

    # Rodar o método de envio
    email_smtp.enviar_email()

    # Verificar se a conexão SMTP foi aberta
    mock_smtp.assert_called_with(email_smtp.servidor, email_smtp.porta)

    # Verificar se o login foi chamado
    instance = mock_smtp.return_value.__enter__.return_value
    instance.login.assert_called_with(
        email_smtp.email,
        email_smtp.senha.get_secret_value()
    )

    # Verificar se o e-mail foi enviado
    instance.sendmail.assert_called()

@patch("advys_servicos.email_smtp.open", create=True)
def test_anexar_arquivo(mock_open, email_smtp, tmp_path):
    # Simular arquivo temporário
    fake_file = tmp_path / "teste.txt"
    fake_file.write_text("conteudo do arquivo")

    # Criar o e-mail primeiro
    email_smtp.criar_email_mime(
        destinatarios=DESTINATARIO,
        assunto=ASSUNTO,
        mensagem=MENSAGEM
    )

    # Mock do open
    mock_open.return_value.__enter__.return_value.read.return_value = b"conteudo do arquivo"

    # Executa anexar
    email_smtp.anexar_arquivo([fake_file])

    # Verifica se open foi chamado
    mock_open.assert_called_with(fake_file, "rb")


from pathlib import Path
from advys_estrutura.config import ENCODING


def cria_arquivo_python(arquivo: Path) -> None:
    """
    Cria um novo arquivo e define uma variável `home`.

    Verifica se o arquivo inserido é um arquivo Python(.py) válido!

    Args:
        arquivo (Path): O nome do arquivo a ser criado.

    """

    if arquivo.suffix != ".py":
        raise ValueError(f'Arquivo Python inválido: {arquivo.stem}')

    with open(arquivo, "w", encoding=ENCODING) as arquivo_py:
        arquivo_py.write("from pathlib import Path\n\n")
        arquivo_py.write(f"home = Path.home()\n\n")


def adiciona_linha_ao_arquivo(row, arquivo:Path):
    """
    Adiciona linha ao final de um arquivo.

    Verifica se o arquivo inserido é um arquivo Python(.py) válido!

    Args:
        arquivo (Path): O nome do arquivo a ser criado.

    """


    if arquivo.suffix != ".py":
        raise ValueError(f'Arquivo Python inválido: {arquivo.stem}')


    with open(arquivo, mode="a+", encoding=ENCODING) as arquivo_py:
        arquivo_py.write(f"{row}\n")



import argparse
from pathlib import Path
import re

# módulos instalados
from unidecode import unidecode

# módulos criados
from advys_configuracoes.config_ini import carrega_configuracao_ini
from advys_estrutura.config import CAMINHOS_PY
from advys_estrutura.utils import cria_arquivo_python, adiciona_linha_ao_arquivo
from advys_utilitarios.arquivos_json import ler_json


def cria_variavel(prefixo, nome):
    # Validações
    if not isinstance(prefixo, str):
        raise ValueError("O argumento 'prefixo' deve ser uma string.")
    if not isinstance(nome, str):
        raise ValueError("O argumento 'nome' deve ser uma string.")

    nome = re.sub("[.-/\\ ]", "_", nome)
    variavel = unidecode(f"{prefixo[:3]}_" + nome).upper()

    return variavel


def criar_caminhos_estrutura(
    arquivo: Path,
    estrutura: list[dict],
    raiz: Path,
    iniciar: bool = True
):
    if iniciar:
        cria_arquivo_python(arquivo)
    for item in estrutura:
        nome = item["nome"]
        tipo = item["tipo"]
        conteudo = item.get("conteudo")
        caminho = Path(raiz) / f"{nome}"
        if tipo == "diretório" and not caminho.exists():
            caminho.mkdir(exist_ok=True, parents=True)
        var = cria_variavel(tipo, nome)
        linha = (
            f"{var} = home / '{caminho.relative_to(Path.home()).as_posix()}'"
        )
        adiciona_linha_ao_arquivo(linha, arquivo)
        if conteudo:
            criar_caminhos_estrutura(
                arquivo,
                conteudo,
                caminho,
                iniciar=False
            )

def executa_atualizacao():
    # Carrega o arquivo de configuração
    config_ini = carrega_configuracao_ini()

    # Cria parametros
    parser = argparse.ArgumentParser(
        description=(
            "Cria estrutura de diretórios e caminhos Python baseada em "
            "um arquivo JSON."
        )
    )

    # Parâmetro --caminho_estrutura
    parser.add_argument(
        "-ce",
        "--caminho_estrutura",
        help=(
            "Caminho para o arquivo JSON que define a estrutura de "
            "diretórios."
        ),
        type=Path
    )

    # Parâmetro --raiz
    parser.add_argument(
        "-r",
        "--raiz",
        help="Caminho raiz onde a estrutura será criada.",
        type=Path
    )

    # Captura os parametros chamados
    args = parser.parse_args()

    # Pega o caminho raiz definido no arquivo de configuração .ini caso não
    # tenha passado um parâmetro ao executar o script
    raiz = config_ini["atualiza_caminhos"]["raiz"]
    if args.raiz:
        raiz = Path(args.raiz)

    # Pega o caminho da estrutura no arquivo de configuração .ini caso não seja
    # passado nenhum parâmetro ao executar o script
    caminho_estrutura_json = (
        Path(config_ini["atualiza_caminhos"]["caminho_estrutura"])
    )
    if args.caminho_estrutura:
        caminho_estrutura_json = Path(args.caminho_estrutura)

    estrutura = ler_json(caminho_estrutura_json)

    criar_caminhos_estrutura(CAMINHOS_PY, estrutura, raiz, iniciar=True)


if __name__ == "__main__":
    executa_atualizacao()



from configparser import ConfigParser
import logging
from pathlib import Path

from advys_configuracoes.constantes import ENCODING, NOME_BIBLIOTECA
from advys_validadores.arquivo import verifica_arquivo

nome_arquivo_ini = "py_advys.ini"
dir_config = Path.home() / f".{NOME_BIBLIOTECA} Config"
arquivo_ini = dir_config / nome_arquivo_ini


def caminho_configuracao_ini():
    return arquivo_ini


def cria_pyadvys_ini(arquivo_config: Path = arquivo_ini):
    """
    Cria um arquivo de configuração .ini padrão para a biblioteca.
    """

    if arquivo_config.exists():
        logging.info(
            f"Arquivo {arquivo_config.name} já existe, pulando a criação..."
        )
        return

    logging.info(f"Criando arquivo {arquivo_config.name}...")

    # Configuração padrão se o ARQUIVO DE CONFIGURAÇÃO não existir
    config = ConfigParser()

    # Configura parâmetros - estrutura/atualiza_estrutura.py
    caminho_estrutura = Path.cwd() / "src" / "estrutura_dir.json"
    raiz = dir_config / "Estrutura"
    raiz.mkdir(parents=True, exist_ok=True)
    config['atualiza_caminhos'] = {
        "caminho_estrutura": str(caminho_estrutura),
        "raiz": str(raiz)
    }

    # Configura parâmetros - estrutura/atualiza_imagens.py
    caminho_imagens = Path.home() / "Imagens Automação Advys"
    caminho_imagens.mkdir(parents=True, exist_ok=True)
    config['atualiza_imagens'] = {
        "caminho_imagens": str(caminho_imagens)
    }

    # Escreve as configurações no arquivo
    with open(arquivo_config, "w", encoding=ENCODING) as a:
        config.write(a)

    logging.info(f"Arquivo {nome_arquivo_ini} criado.")


def carrega_configuracao_ini(arquivo_config: Path = arquivo_ini):
    """
    Carrega o arquivo de configuração .ini
    """

    logging.info(f"Carregando arquivo {arquivo_config.name}")
    arquivo = verifica_arquivo(arquivo_config)
    config = ConfigParser()
    config.read(arquivo.caminho, encoding=ENCODING)
    return config


if __name__ == "__main__":
    py_advys_ini = caminho_configuracao_ini()
    cria_pyadvys_ini()
    verifica_arquivo(py_advys_ini)



import logging
import openpyxl
from pathlib import Path

import pandas as pd
from advys_validadores.arquivo import verifica_arquivo


class ArquivoExcel:
    # Construtor e inicizizção
    def __init__(self, caminho: Path):
        self.caminho_arquivo = caminho
        self.nome_arquivo = caminho.name
        self.cria_arquivo_xlsx()

    def cria_arquivo_xlsx(self) -> None:
        extensao_valida = self.caminho_arquivo.suffix.lower() == ".xlsx"
        if self.caminho_arquivo.exists() and extensao_valida:
            self.arquivo = openpyxl.load_workbook(self.caminho_arquivo)
            logging.info(
                f"Arquivo {self.caminho_arquivo.name} carregado."
            )
        else:
            self.arquivo = openpyxl.Workbook()
            logging.info(f"Arquivo {self.caminho_arquivo.name} criado.")

    # Métodos principais
    def cria_planilha(self, nome_planilha: str) -> None:
        self._seleciona_ou_cria_planilha(nome_planilha)

    def selecionar_planilha(self, nome_planilha: str) -> None:
        self._seleciona_ou_cria_planilha(nome_planilha)

    def adiciona_nome_coluna(self, nome: str, coluna: int) -> None:
        if not isinstance(coluna, int) or coluna < 1:
            raise ValueError(f"Coluna {coluna} inválida!")
        self.planilha.cell(row=1, column=coluna, value=nome)

    def adiciona_linha(self, linha: list) -> None:
        if linha:
            self.planilha.append(linha)
        else:
            raise ValueError(f"Lista vazia")

    def adiciona_dataframe(self, df: pd.DataFrame) -> None:
        # Insere nome das colunas
        for col_num, value in enumerate(df.columns, start=1):
            self.adiciona_nome_coluna(value, col_num)

        # Insere valores nas linhas
        for linha in df.itertuples(index=False):
            self.planilha.append(linha)

    def salva_arquivo(self) -> None:
        if "Sheet" in self.arquivo.sheetnames:
            self._remover_sheet_padrao()
        self.arquivo.save(str(self.caminho_arquivo))

    # Métodos utilitários
    def limpa_planilha(self, manter_cabecalho: bool = False) -> None:
        if manter_cabecalho and self.planilha.max_row > 1:
            self.planilha.delete_rows(2, self.planilha.max_row - 1)
        else:
            self.planilha.delete_rows(1, self.planilha.max_row)

    def formata_tamanho_colunas(self) -> None:
        for coluna in range(1, self.planilha.max_column + 1):
            max_length = 10
            for linha in range(1, self.planilha.max_row + 1):
                cell = self.planilha.cell(row=linha, column=coluna)
                if cell.value:
                    length = len(str(cell.value))
                    if length > max_length:
                        max_length = length
            self.planilha.column_dimensions[
                self.planilha.cell(row=1, column=coluna).column_letter
            ].width = max_length + 2

    def remove_planilha(self, nome_planilha: str = None) -> None:
        try:
            planilha = (
                self.arquivo[nome_planilha]
                if nome_planilha else self.planilha
            )
            self.arquivo.remove(planilha)
        except Exception as e:
            logging.error(
                f"Erro ao excluir planilha '{planilha.title}': {e}"
            )

    # Métodos Privados
    def _seleciona_ou_cria_planilha(self, nome_planilha: str) -> None:
        try:
            # Verifica se planilha já existe
            if nome_planilha in self.arquivo.sheetnames:
                self.planilha = self.arquivo[nome_planilha]
            else:
                self.planilha = self.arquivo.create_sheet(nome_planilha)
                logging.info(f"Planilha {nome_planilha} criada.")
        except Exception as e:
            logging.error(f"Erro ao criar planilha {nome_planilha}: {e}")

    def _remover_sheet_padrao(self) -> None:
        try:
            planilha_padrao = self.arquivo["Sheet"]
            self.arquivo.remove(planilha_padrao)
        except KeyError:
            pass  # Sheet já foi removida

    # Gerenciador de contexto
    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        try:
            self.salva_arquivo()
        except Exception as e:
            logging.error(f"Erro ao salvar arquivo: {e}")



import logging
from pathlib import Path
from pydantic import BaseModel, FilePath, ValidationError

class Arquivo(BaseModel):
    caminho: FilePath

def verifica_arquivo(arquivo: Path) -> Arquivo:
    """
    Verifica se o caminho existe e registra o log em caso de erro de validação.
    """
    try:
        return Arquivo(caminho=arquivo)
    except ValidationError as e:
        logging.error(f"Erro no arquivo - {arquivo}: {e}")
        raise



from pathlib import Path

home = Path.home()

DIR_DADOS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados'
ARQ_EMPRESAS_NIBO_JSON = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/empresas_nibo.json'
ARQ_EMPRESAS_ATIVAS_DB = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/empresas_ativas.db'
ARQ_EMPRESAS_ACESSORIAS_JSON = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/empresas_acessorias.json'
ARQ_ENTREGAS_ACESSORIAS_JSON = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/entregas_acessorias.json'
ARQ_EMPRESAS_DOMINIO_WEB_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Empresas Domínio Web.xlsx'
ARQ_CLIENTES_INADIMPLENTES_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Clientes Inadimplentes.xlsx'
ARQ_RELATORIO_DE_CLIENTES_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Relatório de Clientes.xlsx'
ARQ_EMPRESAS_ACESSORIAS_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Empresas Acessórias.xlsx'
ARQ_ENTREGAS_ACESSORIAS_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Entregas Acessórias.xlsx'
ARQ_OBRIGACOES_ACESSORIAS_XLSX = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Dados/Obrigações Acessórias.xlsx'
DIR_EMPRESAS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Empresas'
DIR_NIBO = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Nibo'
DIR_BOLETOS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Nibo/Boletos'
DIR_ACESSORIAS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Acessórias'
DIR_ECONTINUO_UPLOAD = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Acessórias/Econtinuo Upload'
DIR_DOMINIO_WEB = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Domínio Web'
DIR_DEPARTAMENTOS = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos'
DIR_PESSOAL = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Pessoal'
DIR_FISCAL = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Fiscal'
DIR_FINANCEIRO = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Financeiro'
DIR_CONTABIL = home / 'ADVYS ASSESSORIA DE NEGOCIOS EIRELI/Advys - Documentos/COMUM/19- DESENVOLVIMENTO/Automações/Departamentos/Contábil'



import pytest
import json
from pathlib import Path
from tempfile import TemporaryDirectory

from advys_utilitarios.arquivos_json import escrever_json, ler_json  # ajuste para o nome do seu módulo

# Cria um diretório temporário para os testes
@pytest.fixture
def temp_dir():
    with TemporaryDirectory() as tmpdirname:
        yield Path(tmpdirname)

def test_escrever_json_dict(temp_dir):
    caminho = temp_dir / "arquivo.json"
    dados = {"chave": "valor"}

    escrever_json(dados, caminho)

    with open(caminho, encoding="utf-8") as f:
        conteudo = json.load(f)

    assert conteudo == dados

def test_escrever_json_lista(temp_dir):
    caminho = temp_dir / "arquivo.json"
    dados = [1, 2, 3]

    escrever_json(dados, caminho)

    with open(caminho, encoding="utf-8") as f:
        conteudo = json.load(f)

    assert conteudo == dados

def test_escrever_json_dados_invalidos(temp_dir):
    caminho = temp_dir / "arquivo.json"
    dados = "string inválida"

    with pytest.raises(ValueError, match="dados inválidos"):
        escrever_json(dados, caminho)

def test_ler_json_dict(temp_dir):
    caminho = temp_dir / "arquivo.json"
    dados = {"chave": "valor"}

    caminho.write_text(json.dumps(dados), encoding="utf-8")

    resultado = ler_json(caminho)

    assert resultado == dados

def test_ler_json_lista(temp_dir):
    caminho = temp_dir / "arquivo.json"
    dados = [1, 2, 3]

    caminho.write_text(json.dumps(dados), encoding="utf-8")

    resultado = ler_json(caminho)

    assert resultado == dados

def test_ler_json_malformado(temp_dir):
    caminho = temp_dir / "arquivo.json"
    caminho.write_text("{chave sem aspas: valor}", encoding="utf-8")

    with pytest.raises(json.JSONDecodeError):
        ler_json(caminho)

def test_ler_json_dados_invalidos(temp_dir):
    caminho = temp_dir / "arquivo.json"
    caminho.write_text('"string inválida"', encoding="utf-8")

    with pytest.raises(ValueError, match="dados inválidos"):
        ler_json(caminho)



from pathlib import Path

# Codificação padrão
ENCODING = "utf-8"

# Diretório raiz do departamento de desenvolvimento
DIR_DESENVOLVIMENTO_REDE = (
    Path.home()
    / "ADVYS ASSESSORIA DE NEGOCIOS EIRELI"
    / "Advys - Documentos"
    / "COMUM"
    / "19- DESENVOLVIMENTO"
)

# Caminhos para armazenar variáveis
CAMINHOS_PY = Path(__file__).parent / "caminhos.py"
IMAGENS_PY = Path(__file__).parent / "imagens.py"





def main():
    from advys_estrutura import atualiza_caminhos, atualiza_imagens

    atualiza_caminhos.executa_atualizacao()
    atualiza_imagens.executa_atualização()


    print("Estrutura Atualizada")


import json
from pathlib import Path

#
from advys_configuracoes.constantes import ENCODING
from advys_validadores.arquivo import verifica_arquivo


def escrever_json(dados: dict | list, arquivo: Path):
    if not isinstance(dados, (dict, list)):
        raise ValueError(
            f"Arquivo {arquivo} não criado, dados inválidos."
            f"Tipo recebido: {type(dados).__name__}"
        )

    with open(arquivo, "w", encoding=ENCODING) as arq:
        json.dump(dados, arq, indent=4, ensure_ascii=True)


def ler_json(arquivo) -> dict | list:
    arquivo_json = verifica_arquivo(arquivo).caminho
    with open(arquivo_json, encoding=ENCODING) as arq:
        dados = json.load(arq)
    if not isinstance(dados, (dict | list)):
        raise ValueError(
            f"Arquivo {arquivo} não lido, dados inválidos."
        )
    return dados



from pydantic import ValidationError
import pytest

from advys_validadores.emal import *

def test_email_valido():
    usuario = Usuario(email="teste@teste.com")
    assert usuario.email == "teste@teste.com"

def test_email_sem_arroba():
    with pytest.raises(ValidationError):
        Usuario(email="testeteste.com")

def test_email_vazio():
    with pytest.raises(ValidationError):
        Usuario(email="")

def test_email_sem_dominio():
    with pytest.raises(ValidationError):
        Usuario(email="teste@")